import re

def read_file(filename):
    '''Gibt den Inhalt einer Textdatei zurück.''' 
    fd = open(filename, mode='r')
    txt = fd.read()
    fd.close()
    return txt

def parse_doc(document):
    '''Verktorisiert das Textdokument (in Kleinbuchstaben)'''
    wordvec = dict()
    for word in re.findall(r'\b\w+\b', document):
        word = word.lower()
        if word in wordvec:
            wordvec[word] += 1
        else:
            wordvec[word] = 1
    return wordvec

def norm(wordvec):
    '''Gibt die euklidsche Norm des Zählvektors zurück'''
    return sum([wordvec[w]**2 for w in wordvec])**0.5

def docdist(text1, text2):
    '''Berechnet die Dokumentdistanz zwischen text1 und text2'''
    v1 = parse_doc(text1)
    v2 = parse_doc(text2)
    dotprod = 0
    for word in v1:
        if word in v2:
            dotprod += v1[word]*v2[word]
    q = dotprod/norm(v1)/norm(v2)
    return q
    

d1 = read_file('./gedichte/goethe-01.txt')
d2 = read_file('./gedichte/goethe-03.txt')

#d1 = 'die katze'
#d2 = 'die maus'

dd = docdist(d1, d2)
print(dd)

